@@ -108,7 +108,7 @@ class Plugin(metaclass=abc.ABCMeta):
         pass
 
 
-default_plugin = "apt"
+DEFAULT_PLUGIN = "apt"
 
 
 class APTPlugin(Plugin):
@@ -156,7 +156,7 @@ class SnapPlugin(Plugin):
         sudo().cc(["snap", "remove"] + names)
 
 
-plugins = [
+PLUGINS = [
     APTPlugin,
     SnapPlugin,
 ]
@@ -190,7 +190,7 @@ def main():
 
     args = parser.parse_args()
 
-    plugins = [plugin() for plugin in plugins]
+    plugins = [plugin() for plugin in PLUGINS]
 
     command = args._command
     if not command:
@@ -200,7 +200,7 @@ def main():
         conf = dict(installed=[])
         for plugin in plugins:
             for package in plugin.installed():
-                if plugin.id() == default_plugin:
+                if plugin.id() == DEFAULT_PLUGIN:
                     conf["installed"].append(package)
                 else:
                     conf["installed"].append(luxem.Typed(plugin.id(), package))
@@ -221,7 +221,7 @@ def main():
                 plugin = package.name
                 package = package.value
             else:
-                plugin = default_plugin
+                plugin = DEFAULT_PLUGIN
             if isinstance(package, dict):
                 package = package["name"]
             installed.setdefault(plugin, set()).add(package)
